/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.jackie;

import com.aquenos.epics.jackie.diirt.datasource.AbstractJackieDataSourceProvider;
import com.aquenos.epics.jackie.diirt.datasource.JackieDataSource;

/**
 * <p>
 * Provider for {@link JackieDataSource}s that uses the name <em>jackie</em>.
 * </p>
 * 
 * <p>
 * This provider can be on the class-path together with the JCA-based
 * data-source provider. As the JCA-based data-source provider uses a different
 * name (ca), they do not collide. However, this means that process variables
 * using the <em>ca</em> prefix are not going to be provided by EPICS Jackie.
 * Instead, the <em>jackie</em> prefix has to be used.
 * </p>
 * 
 * <p>
 * When the JCA-based data-source provider is not on the class-path, the
 * {@code CaDataSourceProvider} can be used instead. That provider uses the name
 * <em>ca</em> which means that process variables using the <em>ca</em> prefix
 * can be handled by that provider.
 * </p>
 * 
 * @author Sebastian Marsching
 */
public class JackieDataSourceProvider extends AbstractJackieDataSourceProvider {

    @Override
    public String getName() {
        return "jackie";
    }

}
