/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.internal;

import org.diirt.vtype.VEnum;
import org.diirt.vtype.VEnumArray;

import com.aquenos.epics.jackie.common.value.ChannelAccessGraphicsEnum;
import com.aquenos.epics.jackie.common.value.ChannelAccessTimeEnum;
import com.aquenos.epics.jackie.common.value.ChannelAccessValueType;
import com.aquenos.epics.jackie.diirt.vtype.JackieVEnumArray;

/**
 * Type adapter that convert from {@link ChannelAccessGraphicsEnum} and
 * {@link ChannelAccessTimeEnum} to {@link VEnum}.
 * 
 * @author Sebastian Marsching
 */
public class ArrayEnumTypeAdapter
        extends JackieDataSourceTypeAdapter<VEnumArray> {

    /**
     * Single instance of this adapter.
     */
    public static final ArrayEnumTypeAdapter INSTANCE = new ArrayEnumTypeAdapter();

    private ArrayEnumTypeAdapter() {
        super(true, ChannelAccessValueType.DBR_ENUM, VEnumArray.class);
    }

    @Override
    protected VEnumArray convertValue(JackieConnectionPayload connection,
            JackieMessagePayload message) {
        // We can safely make a cast here because this adapter is only used if
        // the channel's native type is DBR_SHORT and we thus know that the
        // monitors return a DBR_CTRL_SHORT and DBR_TIME_SHORT.
        ChannelAccessGraphicsEnum graphicsValue = (ChannelAccessGraphicsEnum) message
                .getControlsValue();
        ChannelAccessTimeEnum timeValue = (ChannelAccessTimeEnum) message
                .getTimeValue();
        return new JackieVEnumArray(graphicsValue, timeValue,
                connection.getDisconnectTime());
    }

}
